@@ -62,7 +62,9 @@ pub enum ErrorType {
     #[strum(message = "Field required")]
     Missing,
     #[strum(message = "Field is frozen")]
-    Frozen,
+    FrozenField,
+    #[strum(message = "Instance is frozen")]
+    FrozenInstance,
     #[strum(message = "Extra inputs are not permitted")]
     ExtraForbidden,
     #[strum(message = "Keys should be strings")]
