@@ -17,72 +17,123 @@ def schema(*, strict: bool = False) -> dict:
             'type': 'typed-dict',
             'return_fields_set': True,
             'fields': {
-                'field_str': {'schema': {'type': 'str'}},
-                'field_str_con': {'schema': {'type': 'str', 'min_length': 3, 'max_length': 5, 'pattern': '^[a-z]+$'}},
-                'field_int': {'schema': {'type': 'int'}},
-                'field_int_con': {'schema': {'type': 'int', 'gt': 1, 'lt': 10, 'multiple_of': 2}},
-                'field_float': {'schema': {'type': 'float'}},
-                'field_float_con': {'schema': {'type': 'float', 'ge': 1.0, 'le': 10.0, 'multiple_of': 0.5}},
-                'field_bool': {'schema': {'type': 'bool'}},
-                'field_bytes': {'schema': {'type': 'bytes'}},
-                'field_bytes_con': {'schema': {'type': 'bytes', 'min_length': 6, 'max_length': 1000}},
-                'field_date': {'schema': {'type': 'date'}},
-                'field_date_con': {'schema': {'type': 'date', 'ge': '2020-01-01', 'lt': '2020-01-02'}},
-                'field_time': {'schema': {'type': 'time'}},
-                'field_time_con': {'schema': {'type': 'time', 'ge': '06:00:00', 'lt': '12:13:14'}},
-                'field_datetime': {'schema': {'type': 'datetime'}},
+                'field_str': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                'field_str_con': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'str', 'min_length': 3, 'max_length': 5, 'pattern': '^[a-z]+$'},
+                },
+                'field_int': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+                'field_int_con': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'int', 'gt': 1, 'lt': 10, 'multiple_of': 2},
+                },
+                'field_float': {'type': 'typed-dict-field', 'schema': {'type': 'float'}},
+                'field_float_con': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'float', 'ge': 1.0, 'le': 10.0, 'multiple_of': 0.5},
+                },
+                'field_bool': {'type': 'typed-dict-field', 'schema': {'type': 'bool'}},
+                'field_bytes': {'type': 'typed-dict-field', 'schema': {'type': 'bytes'}},
+                'field_bytes_con': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'bytes', 'min_length': 6, 'max_length': 1000},
+                },
+                'field_date': {'type': 'typed-dict-field', 'schema': {'type': 'date'}},
+                'field_date_con': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'date', 'ge': '2020-01-01', 'lt': '2020-01-02'},
+                },
+                'field_time': {'type': 'typed-dict-field', 'schema': {'type': 'time'}},
+                'field_time_con': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'time', 'ge': '06:00:00', 'lt': '12:13:14'},
+                },
+                'field_datetime': {'type': 'typed-dict-field', 'schema': {'type': 'datetime'}},
                 'field_datetime_con': {
-                    'schema': {'type': 'datetime', 'ge': '2000-01-01T06:00:00', 'lt': '2020-01-02T12:13:14'}
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'datetime', 'ge': '2000-01-01T06:00:00', 'lt': '2020-01-02T12:13:14'},
+                },
+                'field_list_any': {'type': 'typed-dict-field', 'schema': {'type': 'list'}},
+                'field_list_str': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'list', 'items_schema': {'type': 'str'}},
                 },
-                'field_list_any': {'schema': {'type': 'list'}},
-                'field_list_str': {'schema': {'type': 'list', 'items_schema': {'type': 'str'}}},
                 'field_list_str_con': {
-                    'schema': {'type': 'list', 'items_schema': {'type': 'str'}, 'min_length': 3, 'max_length': 42}
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'list', 'items_schema': {'type': 'str'}, 'min_length': 3, 'max_length': 42},
+                },
+                'field_set_any': {'type': 'typed-dict-field', 'schema': {'type': 'set'}},
+                'field_set_int': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'set', 'items_schema': {'type': 'int'}},
                 },
-                'field_set_any': {'schema': {'type': 'set'}},
-                'field_set_int': {'schema': {'type': 'set', 'items_schema': {'type': 'int'}}},
                 'field_set_int_con': {
-                    'schema': {'type': 'set', 'items_schema': {'type': 'int'}, 'min_length': 3, 'max_length': 42}
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'set', 'items_schema': {'type': 'int'}, 'min_length': 3, 'max_length': 42},
+                },
+                'field_frozenset_any': {'type': 'typed-dict-field', 'schema': {'type': 'frozenset'}},
+                'field_frozenset_bytes': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'frozenset', 'items_schema': {'type': 'bytes'}},
                 },
-                'field_frozenset_any': {'schema': {'type': 'frozenset'}},
-                'field_frozenset_bytes': {'schema': {'type': 'frozenset', 'items_schema': {'type': 'bytes'}}},
                 'field_frozenset_bytes_con': {
+                    'type': 'typed-dict-field',
                     'schema': {
                         'type': 'frozenset',
                         'items_schema': {'type': 'bytes'},
                         'min_length': 3,
                         'max_length': 42,
-                    }
+                    },
+                },
+                'field_tuple_var_len_any': {'type': 'typed-dict-field', 'schema': {'type': 'tuple-variable'}},
+                'field_tuple_var_len_float': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'tuple-variable', 'items_schema': {'type': 'float'}},
                 },
-                'field_tuple_var_len_any': {'schema': {'type': 'tuple-variable'}},
-                'field_tuple_var_len_float': {'schema': {'type': 'tuple-variable', 'items_schema': {'type': 'float'}}},
                 'field_tuple_var_len_float_con': {
+                    'type': 'typed-dict-field',
                     'schema': {
                         'type': 'tuple-variable',
                         'items_schema': {'type': 'float'},
                         'min_length': 3,
                         'max_length': 42,
-                    }
+                    },
                 },
                 'field_tuple_fix_len': {
+                    'type': 'typed-dict-field',
                     'schema': {
                         'type': 'tuple-positional',
                         'items_schema': [{'type': 'str'}, {'type': 'int'}, {'type': 'float'}, {'type': 'bool'}],
-                    }
+                    },
                 },
-                'field_dict_any': {'schema': {'type': 'dict'}},
+                'field_dict_any': {'type': 'typed-dict-field', 'schema': {'type': 'dict'}},
                 'field_dict_str_float': {
-                    'schema': {'type': 'dict', 'keys_schema': {'type': 'str'}, 'values_schema': {'type': 'float'}}
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'dict', 'keys_schema': {'type': 'str'}, 'values_schema': {'type': 'float'}},
+                },
+                'field_literal_1_int': {'type': 'typed-dict-field', 'schema': {'type': 'literal', 'expected': [1]}},
+                'field_literal_1_str': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'literal', 'expected': ['foobar']},
+                },
+                'field_literal_mult_int': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'literal', 'expected': [1, 2, 3]},
+                },
+                'field_literal_mult_str': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'literal', 'expected': ['foo', 'bar', 'baz']},
+                },
+                'field_literal_assorted': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'literal', 'expected': [1, 'foo', True]},
                 },
-                'field_literal_1_int': {'schema': {'type': 'literal', 'expected': [1]}},
-                'field_literal_1_str': {'schema': {'type': 'literal', 'expected': ['foobar']}},
-                'field_literal_mult_int': {'schema': {'type': 'literal', 'expected': [1, 2, 3]}},
-                'field_literal_mult_str': {'schema': {'type': 'literal', 'expected': ['foo', 'bar', 'baz']}},
-                'field_literal_assorted': {'schema': {'type': 'literal', 'expected': [1, 'foo', True]}},
                 'field_list_nullable_int': {
-                    'schema': {'type': 'list', 'items_schema': {'type': 'nullable', 'schema': {'type': 'int'}}}
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'list', 'items_schema': {'type': 'nullable', 'schema': {'type': 'int'}}},
                 },
                 'field_union': {
+                    'type': 'typed-dict-field',
                     'schema': {
                         'type': 'union',
                         'choices': [
@@ -90,63 +141,70 @@ def schema(*, strict: bool = False) -> dict:
                             {
                                 'type': 'typed-dict',
                                 'fields': {
-                                    'field_str': {'schema': {'type': 'str'}},
-                                    'field_int': {'schema': {'type': 'int'}},
-                                    'field_float': {'schema': {'type': 'float'}},
+                                    'field_str': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                                    'field_int': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+                                    'field_float': {'type': 'typed-dict-field', 'schema': {'type': 'float'}},
                                 },
                             },
                             {
                                 'type': 'typed-dict',
                                 'fields': {
-                                    'field_float': {'schema': {'type': 'float'}},
-                                    'field_bytes': {'schema': {'type': 'bytes'}},
-                                    'field_date': {'schema': {'type': 'date'}},
+                                    'field_float': {'type': 'typed-dict-field', 'schema': {'type': 'float'}},
+                                    'field_bytes': {'type': 'typed-dict-field', 'schema': {'type': 'bytes'}},
+                                    'field_date': {'type': 'typed-dict-field', 'schema': {'type': 'date'}},
                                 },
                             },
                         ],
-                    }
+                    },
                 },
                 'field_functions_model': {
+                    'type': 'typed-dict-field',
                     'schema': {
                         'type': 'typed-dict',
                         'fields': {
                             'field_before': {
+                                'type': 'typed-dict-field',
                                 'schema': {
                                     'type': 'function-before',
                                     'function': {'type': 'general', 'function': append_func},
                                     'schema': {'type': 'str'},
-                                }
+                                },
                             },
                             'field_after': {
+                                'type': 'typed-dict-field',
                                 'schema': {
                                     'type': 'function-after',
                                     'function': {'type': 'general', 'function': append_func},
                                     'schema': {'type': 'str'},
-                                }
+                                },
                             },
                             'field_wrap': {
+                                'type': 'typed-dict-field',
                                 'schema': {
                                     'type': 'function-wrap',
                                     'function': {'type': 'general', 'function': wrap_function},
                                     'schema': {'type': 'str'},
-                                }
+                                },
                             },
                             'field_plain': {
+                                'type': 'typed-dict-field',
                                 'schema': {
                                     'type': 'function-plain',
                                     'function': {'type': 'general', 'function': append_func},
-                                }
+                                },
                             },
                         },
-                    }
+                    },
                 },
                 'field_recursive': {
+                    'type': 'typed-dict-field',
                     'schema': {
                         'ref': 'Branch',
                         'type': 'typed-dict',
                         'fields': {
-                            'name': {'schema': {'type': 'str'}},
+                            'name': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
                             'sub_branch': {
+                                'type': 'typed-dict-field',
                                 'schema': {
                                     'type': 'default',
                                     'schema': {
@@ -154,10 +212,10 @@ def schema(*, strict: bool = False) -> dict:
                                         'schema': {'type': 'definition-ref', 'schema_ref': 'Branch'},
                                     },
                                     'default': None,
-                                }
+                                },
                             },
                         },
-                    }
+                    },
                 },
             },
         },
@@ -207,7 +265,7 @@ def pydantic_model():
 
     class Model(BaseModel):
         field_str: str
-        field_str_con: constr(min_length=3, max_length=5, regex='^[a-z]+$')  # noqa F722
+        field_str_con: constr(min_length=3, max_length=5, regex='^[a-z]+$')
         field_int: int
         field_int_con: conint(gt=1, lt=10, multiple_of=2)
         field_float: float
