@@ -53,7 +53,11 @@ def test_internal_error():
         {
             'type': 'model',
             'cls': int,
-            'schema': {'type': 'typed-dict', 'return_fields_set': True, 'fields': {'f': {'schema': {'type': 'int'}}}},
+            'schema': {
+                'type': 'typed-dict',
+                'return_fields_set': True,
+                'fields': {'f': {'type': 'typed-dict-field', 'schema': {'type': 'int'}}},
+            },
         }
     )
     with pytest.raises(AttributeError, match="'int' object has no attribute '__dict__'"):
