@@ -154,11 +154,15 @@ all_schema_functions = [
         args({'type': 'int'}, {'type': 'str'}),
         {'type': 'chain', 'steps': [{'type': 'int'}, {'type': 'str'}]},
     ),
-    (core_schema.typed_dict_field, args({'type': 'int'}, required=True), {'schema': {'type': 'int'}, 'required': True}),
+    (
+        core_schema.typed_dict_field,
+        args({'type': 'int'}, required=True),
+        {'type': 'typed-dict-field', 'schema': {'type': 'int'}, 'required': True},
+    ),
     (
         core_schema.typed_dict_schema,
         args({'foo': core_schema.typed_dict_field({'type': 'int'})}),
-        {'type': 'typed-dict', 'fields': {'foo': {'schema': {'type': 'int'}}}},
+        {'type': 'typed-dict', 'fields': {'foo': {'type': 'typed-dict-field', 'schema': {'type': 'int'}}}},
     ),
     (
         core_schema.model_schema,
@@ -218,8 +222,12 @@ all_schema_functions = [
     (core_schema.definition_reference_schema, args('foo'), {'type': 'definition-ref', 'schema_ref': 'foo'}),
     (
         core_schema.dataclass_args_schema,
-        args('Foo', [{'name': 'foo', 'schema': {'type': 'int'}}]),
-        {'type': 'dataclass-args', 'dataclass_name': 'Foo', 'fields': [{'name': 'foo', 'schema': {'type': 'int'}}]},
+        args('Foo', [{'name': 'foo', 'type': 'dataclass-field', 'schema': {'type': 'int'}}]),
+        {
+            'type': 'dataclass-args',
+            'dataclass_name': 'Foo',
+            'fields': [{'name': 'foo', 'type': 'dataclass-field', 'schema': {'type': 'int'}}],
+        },
     ),
     (
         core_schema.dataclass_schema,
@@ -235,7 +243,7 @@ def test_schema_functions(function, args_kwargs, expected_schema):
     args, kwargs = args_kwargs
     schema = function(*args, **kwargs)
     assert schema == expected_schema
-    if schema.get('type') in {None, 'definition-ref'}:
+    if schema.get('type') in {None, 'definition-ref', 'typed-dict-field'}:
         return
 
     v = SchemaValidator(schema)
@@ -255,6 +263,9 @@ def test_all_schema_functions_used():
     }
     types_used = {args['type'] for _, _, args in all_schema_functions if 'type' in args}
 
+    # isn't a CoreSchema type
+    types_used.remove('typed-dict-field')
+
     assert all_types == types_used
 
 
