@@ -43,7 +43,10 @@ def test_simple():
     v = SchemaValidator(
         {
             'type': 'typed-dict',
-            'fields': {'field_a': {'schema': {'type': 'str'}}, 'field_b': {'schema': {'type': 'int'}}},
+            'fields': {
+                'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                'field_b': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+            },
         }
     )
 
@@ -54,7 +57,10 @@ def test_strict():
     v = SchemaValidator(
         {
             'type': 'typed-dict',
-            'fields': {'field_a': {'schema': {'type': 'str'}}, 'field_b': {'schema': {'type': 'int'}}},
+            'fields': {
+                'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                'field_b': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+            },
         },
         {'strict': True},
     )
@@ -75,8 +81,11 @@ def test_with_default():
             'type': 'typed-dict',
             'return_fields_set': True,
             'fields': {
-                'field_a': {'schema': {'type': 'str'}},
-                'field_b': {'schema': {'type': 'default', 'schema': {'type': 'int'}, 'default': 666}},
+                'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                'field_b': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'default', 'schema': {'type': 'int'}, 'default': 666},
+                },
             },
         }
     )
@@ -92,7 +101,10 @@ def test_missing_error():
     v = SchemaValidator(
         {
             'type': 'typed-dict',
-            'fields': {'field_a': {'schema': {'type': 'str'}}, 'field_b': {'schema': {'type': 'int'}}},
+            'fields': {
+                'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                'field_b': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+            },
         }
     )
     with pytest.raises(ValidationError) as exc_info:
@@ -134,7 +146,10 @@ def test_config(config: CoreConfig, input_value, expected):
     v = SchemaValidator(
         {
             'type': 'typed-dict',
-            'fields': {'a': {'schema': {'type': 'int'}}, 'b': {'schema': {'type': 'float'}, 'required': False}},
+            'fields': {
+                'a': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+                'b': {'type': 'typed-dict-field', 'schema': {'type': 'float'}, 'required': False},
+            },
         },
         config,
     )
@@ -152,7 +167,10 @@ def test_ignore_extra():
         {
             'type': 'typed-dict',
             'return_fields_set': True,
-            'fields': {'field_a': {'schema': {'type': 'str'}}, 'field_b': {'schema': {'type': 'int'}}},
+            'fields': {
+                'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                'field_b': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+            },
         }
     )
 
@@ -167,7 +185,7 @@ def test_forbid_extra():
         {
             'type': 'typed-dict',
             'return_fields_set': True,
-            'fields': {'field_a': {'schema': {'type': 'str'}}},
+            'fields': {'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}}},
             'extra_behavior': 'forbid',
         }
     )
@@ -185,7 +203,7 @@ def test_allow_extra():
         {
             'type': 'typed-dict',
             'return_fields_set': True,
-            'fields': {'field_a': {'schema': {'type': 'str'}}},
+            'fields': {'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}}},
             'extra_behavior': 'allow',
         }
     )
@@ -201,7 +219,7 @@ def test_allow_extra_validate():
         {
             'type': 'typed-dict',
             'return_fields_set': True,
-            'fields': {'field_a': {'schema': {'type': 'str'}}},
+            'fields': {'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}}},
             'extra_validator': {'type': 'int'},
             'extra_behavior': 'allow',
         }
@@ -238,7 +256,8 @@ def test_allow_extra_wrong():
 
 def test_str_config():
     v = SchemaValidator(
-        {'type': 'typed-dict', 'fields': {'field_a': {'schema': {'type': 'str'}}}}, {'str_max_length': 5}
+        {'type': 'typed-dict', 'fields': {'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}}}},
+        {'str_max_length': 5},
     )
     assert v.validate_python({'field_a': 'test'}) == {'field_a': 'test'}
 
@@ -248,7 +267,11 @@ def test_str_config():
 
 def test_validate_assignment():
     v = SchemaValidator(
-        {'type': 'typed-dict', 'return_fields_set': True, 'fields': {'field_a': {'schema': {'type': 'str'}}}}
+        {
+            'type': 'typed-dict',
+            'return_fields_set': True,
+            'fields': {'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}}},
+        }
     )
 
     assert v.validate_python({'field_a': 'test'}) == ({'field_a': 'test'}, {'field_a'})
@@ -263,7 +286,7 @@ def test_validate_assignment_strict_field():
         {
             'type': 'typed-dict',
             'return_fields_set': True,
-            'fields': {'field_a': {'schema': {'type': 'str', 'strict': True}}},
+            'fields': {'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str', 'strict': True}}},
         }
     )
 
@@ -293,18 +316,20 @@ def test_validate_assignment_functions():
             'return_fields_set': True,
             'fields': {
                 'field_a': {
+                    'type': 'typed-dict-field',
                     'schema': {
                         'type': 'function-after',
                         'function': {'type': 'general', 'function': func_a},
                         'schema': {'type': 'str'},
-                    }
+                    },
                 },
                 'field_b': {
+                    'type': 'typed-dict-field',
                     'schema': {
                         'type': 'function-after',
                         'function': {'type': 'general', 'function': func_b},
                         'schema': {'type': 'int'},
-                    }
+                    },
                 },
             },
         }
@@ -326,7 +351,11 @@ def test_validate_assignment_functions():
 
 def test_validate_assignment_ignore_extra():
     v = SchemaValidator(
-        {'type': 'typed-dict', 'return_fields_set': True, 'fields': {'field_a': {'schema': {'type': 'str'}}}}
+        {
+            'type': 'typed-dict',
+            'return_fields_set': True,
+            'fields': {'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}}},
+        }
     )
 
     assert v.validate_python({'field_a': 'test'}) == ({'field_a': 'test'}, {'field_a'})
@@ -348,7 +377,11 @@ def test_validate_assignment_ignore_extra():
 
 def test_validate_assignment_allow_extra():
     v = SchemaValidator(
-        {'type': 'typed-dict', 'fields': {'field_a': {'schema': {'type': 'str'}}}, 'extra_behavior': 'allow'}
+        {
+            'type': 'typed-dict',
+            'fields': {'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}}},
+            'extra_behavior': 'allow',
+        }
     )
 
     assert v.validate_python({'field_a': 'test'}) == {'field_a': 'test'}
@@ -360,7 +393,7 @@ def test_validate_assignment_allow_extra_validate():
     v = SchemaValidator(
         {
             'type': 'typed-dict',
-            'fields': {'field_a': {'schema': {'type': 'str'}}},
+            'fields': {'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}}},
             'extra_validator': {'type': 'int'},
             'extra_behavior': 'allow',
         }
@@ -382,7 +415,13 @@ def test_validate_assignment_allow_extra_validate():
 
 def test_validate_assignment_with_strict():
     v = SchemaValidator(
-        {'type': 'typed-dict', 'fields': {'x': {'schema': {'type': 'str'}}, 'y': {'schema': {'type': 'int'}}}}
+        {
+            'type': 'typed-dict',
+            'fields': {
+                'x': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                'y': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+            },
+        }
     )
 
     r = v.validate_python({'x': 'a', 'y': '123'})
@@ -401,7 +440,12 @@ def test_validate_assignment_with_strict():
 
 def test_json_error():
     v = SchemaValidator(
-        {'type': 'typed-dict', 'fields': {'field_a': {'schema': {'type': 'list', 'items_schema': {'type': 'int'}}}}}
+        {
+            'type': 'typed-dict',
+            'fields': {
+                'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'list', 'items_schema': {'type': 'int'}}}
+            },
+        }
     )
     with pytest.raises(ValidationError) as exc_info:
         v.validate_json('{"field_a": [123, "wrong"]}')
@@ -424,7 +468,13 @@ def test_missing_schema_key():
 def test_fields_required_by_default():
     """By default all fields should be required"""
     v = SchemaValidator(
-        {'type': 'typed-dict', 'fields': {'x': {'schema': {'type': 'str'}}, 'y': {'schema': {'type': 'str'}}}}
+        {
+            'type': 'typed-dict',
+            'fields': {
+                'x': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                'y': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+            },
+        }
     )
 
     assert v.validate_python({'x': 'pika', 'y': 'chu'}) == {'x': 'pika', 'y': 'chu'}
@@ -442,7 +492,10 @@ def test_fields_required_by_default_with_optional():
         {
             'type': 'typed-dict',
             'return_fields_set': True,
-            'fields': {'x': {'schema': {'type': 'str'}}, 'y': {'schema': {'type': 'str'}, 'required': False}},
+            'fields': {
+                'x': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                'y': {'type': 'typed-dict-field', 'schema': {'type': 'str'}, 'required': False},
+            },
         }
     )
 
@@ -456,8 +509,11 @@ def test_fields_required_by_default_with_default():
             'type': 'typed-dict',
             'return_fields_set': True,
             'fields': {
-                'x': {'schema': {'type': 'str'}},
-                'y': {'schema': {'type': 'default', 'schema': {'type': 'str'}, 'default': 'bulbi'}},
+                'x': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                'y': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'default', 'schema': {'type': 'str'}, 'default': 'bulbi'},
+                },
             },
         }
     )
@@ -473,7 +529,10 @@ def test_all_optional_fields():
             'type': 'typed-dict',
             'total': False,
             'return_fields_set': True,
-            'fields': {'x': {'schema': {'type': 'str', 'strict': True}}, 'y': {'schema': {'type': 'str'}}},
+            'fields': {
+                'x': {'type': 'typed-dict-field', 'schema': {'type': 'str', 'strict': True}},
+                'y': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+            },
         }
     )
 
@@ -496,8 +555,8 @@ def test_all_optional_fields_with_required_fields():
             'total': False,
             'return_fields_set': True,
             'fields': {
-                'x': {'schema': {'type': 'str', 'strict': True}, 'required': True},
-                'y': {'schema': {'type': 'str'}},
+                'x': {'type': 'typed-dict-field', 'schema': {'type': 'str', 'strict': True}, 'required': True},
+                'y': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
             },
         }
     )
@@ -520,7 +579,11 @@ def test_field_required_and_default():
             {
                 'type': 'typed-dict',
                 'fields': {
-                    'x': {'schema': {'type': 'default', 'schema': {'type': 'str'}, 'default': 'pika'}, 'required': True}
+                    'x': {
+                        'type': 'typed-dict-field',
+                        'schema': {'type': 'default', 'schema': {'type': 'str'}, 'default': 'pika'},
+                        'required': True,
+                    }
                 },
             }
         )
@@ -528,7 +591,12 @@ def test_field_required_and_default():
 
 def test_alias(py_and_json: PyAndJson):
     v = py_and_json(
-        {'type': 'typed-dict', 'fields': {'field_a': {'validation_alias': 'FieldA', 'schema': {'type': 'int'}}}}
+        {
+            'type': 'typed-dict',
+            'fields': {
+                'field_a': {'validation_alias': 'FieldA', 'type': 'typed-dict-field', 'schema': {'type': 'int'}}
+            },
+        }
     )
     assert v.validate_test({'FieldA': '123'}) == {'field_a': 123}
     with pytest.raises(ValidationError, match=r'field_a\n +Field required \[type=missing,'):
@@ -538,16 +606,26 @@ def test_alias(py_and_json: PyAndJson):
 
 
 def test_empty_string_field_name(py_and_json: PyAndJson):
-    v = py_and_json({'type': 'typed-dict', 'fields': {'': {'schema': {'type': 'int'}}}})
+    v = py_and_json({'type': 'typed-dict', 'fields': {'': {'type': 'typed-dict-field', 'schema': {'type': 'int'}}}})
     assert v.validate_test({'': 123}) == {'': 123}
 
 
 def test_empty_string_aliases(py_and_json: PyAndJson):
-    v = py_and_json({'type': 'typed-dict', 'fields': {'field_a': {'validation_alias': '', 'schema': {'type': 'int'}}}})
+    v = py_and_json(
+        {
+            'type': 'typed-dict',
+            'fields': {'field_a': {'validation_alias': '', 'type': 'typed-dict-field', 'schema': {'type': 'int'}}},
+        }
+    )
     assert v.validate_test({'': 123}) == {'field_a': 123}
 
     v = py_and_json(
-        {'type': 'typed-dict', 'fields': {'field_a': {'validation_alias': ['', ''], 'schema': {'type': 'int'}}}}
+        {
+            'type': 'typed-dict',
+            'fields': {
+                'field_a': {'validation_alias': ['', ''], 'type': 'typed-dict-field', 'schema': {'type': 'int'}}
+            },
+        }
     )
     assert v.validate_test({'': {'': 123}}) == {'field_a': 123}
 
@@ -558,7 +636,9 @@ def test_alias_allow_pop(py_and_json: PyAndJson):
             'type': 'typed-dict',
             'return_fields_set': True,
             'populate_by_name': True,
-            'fields': {'field_a': {'validation_alias': 'FieldA', 'schema': {'type': 'int'}}},
+            'fields': {
+                'field_a': {'validation_alias': 'FieldA', 'type': 'typed-dict-field', 'schema': {'type': 'int'}}
+            },
         }
     )
     assert v.validate_test({'FieldA': '123'}) == ({'field_a': 123}, {'field_a'})
@@ -581,7 +661,12 @@ def test_alias_allow_pop(py_and_json: PyAndJson):
 )
 def test_alias_path(py_and_json: PyAndJson, input_value, expected):
     v = py_and_json(
-        {'type': 'typed-dict', 'fields': {'field_a': {'validation_alias': ['foo', 'bar'], 'schema': {'type': 'int'}}}}
+        {
+            'type': 'typed-dict',
+            'fields': {
+                'field_a': {'validation_alias': ['foo', 'bar'], 'type': 'typed-dict-field', 'schema': {'type': 'int'}}
+            },
+        }
     )
     if isinstance(expected, Err):
         with pytest.raises(ValidationError, match=expected.message):
@@ -615,6 +700,7 @@ def test_aliases_path_multiple(py_and_json: PyAndJson, input_value, expected):
             'fields': {
                 'field_a': {
                     'validation_alias': [['foo', 'bar', 'bat'], ['foo', 3], ['spam']],
+                    'type': 'typed-dict-field',
                     'schema': {'type': 'int'},
                 }
             },
@@ -633,7 +719,13 @@ def test_aliases_debug():
     v = SchemaValidator(
         {
             'type': 'typed-dict',
-            'fields': {'field_a': {'validation_alias': [['foo', 'bar', 'bat'], ['foo', 3]], 'schema': {'type': 'int'}}},
+            'fields': {
+                'field_a': {
+                    'validation_alias': [['foo', 'bar', 'bat'], ['foo', 3]],
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'int'},
+                }
+            },
         }
     )
     print(repr(v))
@@ -645,7 +737,13 @@ def get_int_key():
     v = SchemaValidator(
         {
             'type': 'typed-dict',
-            'fields': {'field_a': {'validation_alias': [['foo', 3], ['spam']], 'schema': {'type': 'int'}}},
+            'fields': {
+                'field_a': {
+                    'validation_alias': [['foo', 3], ['spam']],
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'int'},
+                }
+            },
         }
     )
     assert v.validate_python({'foo': {3: 33}}) == ({'field_a': 33}, {'field_a'})
@@ -659,7 +757,10 @@ class GetItemThing:
 
 def get_custom_getitem():
     v = SchemaValidator(
-        {'type': 'typed-dict', 'fields': {'field_a': {'validation_alias': ['foo'], 'schema': {'type': 'int'}}}}
+        {
+            'type': 'typed-dict',
+            'fields': {'field_a': {'validation_alias': ['foo'], 'type': 'typed-dict-field', 'schema': {'type': 'int'}}},
+        }
     )
     assert v.validate_python(GetItemThing()) == ({'field_a': 321}, {'field_a'})
     assert v.validate_python({'bar': GetItemThing()}) == ({'field_a': 321}, {'field_a'})
@@ -670,7 +771,13 @@ def test_paths_allow_by_name(py_and_json: PyAndJson, input_value):
     v = py_and_json(
         {
             'type': 'typed-dict',
-            'fields': {'field_a': {'validation_alias': [['foo', 'bar'], ['foo']], 'schema': {'type': 'int'}}},
+            'fields': {
+                'field_a': {
+                    'validation_alias': [['foo', 'bar'], ['foo']],
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'int'},
+                }
+            },
             'populate_by_name': True,
         }
     )
@@ -691,14 +798,25 @@ def test_paths_allow_by_name(py_and_json: PyAndJson, input_value):
 )
 def test_alias_build_error(alias_schema, error):
     with pytest.raises(SchemaError, match=error):
-        SchemaValidator({'type': 'typed-dict', 'fields': {'field_a': {'schema': {'type': 'int'}, **alias_schema}}})
+        SchemaValidator(
+            {
+                'type': 'typed-dict',
+                'fields': {'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'int'}, **alias_schema}},
+            }
+        )
 
 
 def test_alias_error_loc():
     v = SchemaValidator(
         {
             'type': 'typed-dict',
-            'fields': {'field_a': {'schema': {'type': 'int'}, 'validation_alias': [['bar'], ['foo']]}},
+            'fields': {
+                'field_a': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'int'},
+                    'validation_alias': [['bar'], ['foo']],
+                }
+            },
         }
     )
     assert v.validate_python({'foo': 42}) == {'field_a': 42}
@@ -740,25 +858,27 @@ def test_model_deep():
             'type': 'typed-dict',
             'return_fields_set': True,
             'fields': {
-                'field_a': {'schema': {'type': 'str'}},
+                'field_a': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
                 'field_b': {
+                    'type': 'typed-dict-field',
                     'schema': {
                         'type': 'typed-dict',
                         'return_fields_set': True,
                         'fields': {
-                            'field_c': {'schema': {'type': 'str'}},
+                            'field_c': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
                             'field_d': {
+                                'type': 'typed-dict-field',
                                 'schema': {
                                     'type': 'typed-dict',
                                     'return_fields_set': True,
                                     'fields': {
-                                        'field_e': {'schema': {'type': 'str'}},
-                                        'field_f': {'schema': {'type': 'int'}},
+                                        'field_e': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                                        'field_f': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
                                     },
-                                }
+                                },
                             },
                         },
-                    }
+                    },
                 },
             },
         }
@@ -833,9 +953,9 @@ def test_from_attributes(input_value, expected):
             'type': 'typed-dict',
             'return_fields_set': True,
             'fields': {
-                'a': {'schema': {'type': 'int'}},
-                'b': {'schema': {'type': 'int'}},
-                'c': {'schema': {'type': 'str'}},
+                'a': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+                'b': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+                'c': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
             },
             'from_attributes': True,
         }
@@ -854,9 +974,9 @@ def test_from_attributes_type_error():
         {
             'type': 'typed-dict',
             'fields': {
-                'a': {'schema': {'type': 'int'}},
-                'b': {'schema': {'type': 'int'}},
-                'c': {'schema': {'type': 'str'}},
+                'a': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+                'b': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+                'c': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
             },
             'from_attributes': True,
         }
@@ -879,7 +999,7 @@ def test_from_attributes_by_name():
         {
             'type': 'typed-dict',
             'return_fields_set': True,
-            'fields': {'a': {'schema': {'type': 'int'}, 'validation_alias': 'a_alias'}},
+            'fields': {'a': {'type': 'typed-dict-field', 'schema': {'type': 'int'}, 'validation_alias': 'a_alias'}},
             'from_attributes': True,
             'populate_by_name': True,
         }
@@ -898,9 +1018,9 @@ def test_from_attributes_missing():
         {
             'type': 'typed-dict',
             'fields': {
-                'a': {'schema': {'type': 'int'}},
-                'b': {'schema': {'type': 'int'}},
-                'c': {'schema': {'type': 'str'}},
+                'a': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+                'b': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+                'c': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
             },
             'from_attributes': True,
         }
@@ -931,7 +1051,10 @@ def test_from_attributes_error():
     v = SchemaValidator(
         {
             'type': 'typed-dict',
-            'fields': {'a': {'schema': {'type': 'int'}}, 'b': {'schema': {'type': 'int'}}},
+            'fields': {
+                'a': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+                'b': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
+            },
             'from_attributes': True,
         }
     )
@@ -997,7 +1120,7 @@ def test_from_attributes_extra():
         {
             'type': 'typed-dict',
             'return_fields_set': True,
-            'fields': {'a': {'schema': {'type': 'int'}}},
+            'fields': {'a': {'type': 'typed-dict-field', 'schema': {'type': 'int'}}},
             'from_attributes': True,
             'extra_behavior': 'allow',
         }
@@ -1026,7 +1149,13 @@ def foobar():
     ids=repr,
 )
 def test_from_attributes_function(input_value, expected):
-    v = SchemaValidator({'type': 'typed-dict', 'fields': {'a': {'schema': {'type': 'any'}}}, 'from_attributes': True})
+    v = SchemaValidator(
+        {
+            'type': 'typed-dict',
+            'fields': {'a': {'type': 'typed-dict-field', 'schema': {'type': 'any'}}},
+            'from_attributes': True,
+        }
+    )
 
     assert v.validate_python(input_value) == expected
 
@@ -1041,7 +1170,13 @@ def test_from_attributes_error_error():
         def x(self):
             raise BadError('intentional error')
 
-    v = SchemaValidator({'type': 'typed-dict', 'fields': {'x': {'schema': {'type': 'int'}}}, 'from_attributes': True})
+    v = SchemaValidator(
+        {
+            'type': 'typed-dict',
+            'fields': {'x': {'type': 'typed-dict-field', 'schema': {'type': 'int'}}},
+            'from_attributes': True,
+        }
+    )
 
     with pytest.raises(ValidationError) as exc_info:
         v.validate_python(Foobar())
@@ -1100,6 +1235,7 @@ def test_from_attributes_path(input_value, expected):
             'fields': {
                 'my_field': {
                     'validation_alias': [['foo', 'bar', 'bat'], ['foo', 3], ['spam']],
+                    'type': 'typed-dict-field',
                     'schema': {'type': 'int'},
                 }
             },
@@ -1127,6 +1263,7 @@ def test_from_attributes_path_error():
             'fields': {
                 'my_field': {
                     'validation_alias': [['foo', 'bar', 'bat'], ['foo', 3], ['spam']],
+                    'type': 'typed-dict-field',
                     'schema': {'type': 'int'},
                 }
             },
@@ -1152,7 +1289,13 @@ def test_alias_extra(py_and_json: PyAndJson):
         {
             'type': 'typed-dict',
             'extra_behavior': 'allow',
-            'fields': {'field_a': {'validation_alias': [['FieldA'], ['foo', 2]], 'schema': {'type': 'int'}}},
+            'fields': {
+                'field_a': {
+                    'validation_alias': [['FieldA'], ['foo', 2]],
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'int'},
+                }
+            },
         }
     )
     assert v.validate_test({'FieldA': 1}) == {'field_a': 1}
@@ -1178,7 +1321,13 @@ def test_alias_extra_from_attributes():
             'type': 'typed-dict',
             'extra_behavior': 'allow',
             'from_attributes': True,
-            'fields': {'field_a': {'validation_alias': [['FieldA'], ['foo', 2]], 'schema': {'type': 'int'}}},
+            'fields': {
+                'field_a': {
+                    'validation_alias': [['FieldA'], ['foo', 2]],
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'int'},
+                }
+            },
         }
     )
     assert v.validate_python({'FieldA': 1}) == {'field_a': 1}
@@ -1194,7 +1343,9 @@ def test_alias_extra_by_name(py_and_json: PyAndJson):
             'extra_behavior': 'allow',
             'from_attributes': True,
             'populate_by_name': True,
-            'fields': {'field_a': {'validation_alias': 'FieldA', 'schema': {'type': 'int'}}},
+            'fields': {
+                'field_a': {'validation_alias': 'FieldA', 'type': 'typed-dict-field', 'schema': {'type': 'int'}}
+            },
         }
     )
     assert v.validate_test({'FieldA': 1}) == {'field_a': 1}
@@ -1208,7 +1359,9 @@ def test_alias_extra_forbid(py_and_json: PyAndJson):
         {
             'type': 'typed-dict',
             'extra_behavior': 'forbid',
-            'fields': {'field_a': {'validation_alias': 'FieldA', 'schema': {'type': 'int'}}},
+            'fields': {
+                'field_a': {'type': 'typed-dict-field', 'validation_alias': 'FieldA', 'schema': {'type': 'int'}}
+            },
         }
     )
     assert v.validate_test({'FieldA': 1}) == {'field_a': 1}
@@ -1219,7 +1372,10 @@ def test_with_default_factory():
         {
             'type': 'typed-dict',
             'fields': {
-                'x': {'schema': {'type': 'default', 'schema': {'type': 'str'}, 'default_factory': lambda: 'pikachu'}}
+                'x': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'default', 'schema': {'type': 'str'}, 'default_factory': lambda: 'pikachu'},
+                }
             },
         }
     )
@@ -1236,6 +1392,7 @@ def test_field_required_and_default_factory():
                 'type': 'typed-dict',
                 'fields': {
                     'x': {
+                        'type': 'typed-dict-field',
                         'schema': {'type': 'default', 'schema': {'type': 'str'}, 'default_factory': lambda: 'pika'},
                         'required': True,
                     }
@@ -1256,7 +1413,10 @@ def test_bad_default_factory(default_factory, error_message):
         {
             'type': 'typed-dict',
             'fields': {
-                'x': {'schema': {'type': 'default', 'schema': {'type': 'str'}, 'default_factory': default_factory}}
+                'x': {
+                    'type': 'typed-dict-field',
+                    'schema': {'type': 'default', 'schema': {'type': 'str'}, 'default_factory': default_factory},
+                }
             },
         }
     )
@@ -1270,7 +1430,12 @@ class TestOnError:
             SchemaValidator(
                 {
                     'type': 'typed-dict',
-                    'fields': {'x': {'schema': {'type': 'default', 'schema': {'type': 'str'}, 'on_error': 'rais'}}},
+                    'fields': {
+                        'x': {
+                            'type': 'typed-dict-field',
+                            'schema': {'type': 'default', 'schema': {'type': 'str'}, 'on_error': 'rais'},
+                        }
+                    },
                 }
             )
 
@@ -1279,7 +1444,12 @@ class TestOnError:
             SchemaValidator(
                 {
                     'type': 'typed-dict',
-                    'fields': {'x': {'schema': {'type': 'default', 'schema': {'type': 'str'}, 'on_error': 'omit'}}},
+                    'fields': {
+                        'x': {
+                            'type': 'typed-dict-field',
+                            'schema': {'type': 'default', 'schema': {'type': 'str'}, 'on_error': 'omit'},
+                        }
+                    },
                 }
             )
 
@@ -1288,12 +1458,19 @@ class TestOnError:
             SchemaValidator(
                 {
                     'type': 'typed-dict',
-                    'fields': {'x': {'schema': {'type': 'default', 'schema': {'type': 'str'}, 'on_error': 'default'}}},
+                    'fields': {
+                        'x': {
+                            'type': 'typed-dict-field',
+                            'schema': {'type': 'default', 'schema': {'type': 'str'}, 'on_error': 'default'},
+                        }
+                    },
                 }
             )
 
     def test_on_error_raise_by_default(self, py_and_json: PyAndJson):
-        v = py_and_json({'type': 'typed-dict', 'fields': {'x': {'schema': {'type': 'str'}}}})
+        v = py_and_json(
+            {'type': 'typed-dict', 'fields': {'x': {'type': 'typed-dict-field', 'schema': {'type': 'str'}}}}
+        )
         assert v.validate_test({'x': 'foo'}) == {'x': 'foo'}
         with pytest.raises(ValidationError) as exc_info:
             v.validate_test({'x': ['foo']})
@@ -1305,7 +1482,12 @@ class TestOnError:
         v = py_and_json(
             {
                 'type': 'typed-dict',
-                'fields': {'x': {'schema': {'type': 'default', 'schema': {'type': 'str'}, 'on_error': 'raise'}}},
+                'fields': {
+                    'x': {
+                        'type': 'typed-dict-field',
+                        'schema': {'type': 'default', 'schema': {'type': 'str'}, 'on_error': 'raise'},
+                    }
+                },
             }
         )
         assert v.validate_test({'x': 'foo'}) == {'x': 'foo'}
@@ -1321,6 +1503,7 @@ class TestOnError:
                 'type': 'typed-dict',
                 'fields': {
                     'x': {
+                        'type': 'typed-dict-field',
                         'schema': {'type': 'default', 'schema': {'type': 'str'}, 'on_error': 'omit'},
                         'required': False,
                     }
@@ -1337,6 +1520,7 @@ class TestOnError:
                 'type': 'typed-dict',
                 'fields': {
                     'x': {
+                        'type': 'typed-dict-field',
                         'schema': {'type': 'default', 'schema': {'type': 'str'}, 'on_error': 'omit', 'default': 'pika'},
                         'required': False,
                     }
@@ -1353,12 +1537,13 @@ class TestOnError:
                 'type': 'typed-dict',
                 'fields': {
                     'x': {
+                        'type': 'typed-dict-field',
                         'schema': {
                             'type': 'default',
                             'schema': {'type': 'str'},
                             'on_error': 'default',
                             'default': 'pika',
-                        }
+                        },
                     }
                 },
             }
@@ -1372,12 +1557,13 @@ class TestOnError:
                 'type': 'typed-dict',
                 'fields': {
                     'x': {
+                        'type': 'typed-dict-field',
                         'schema': {
                             'type': 'default',
                             'schema': {'type': 'str'},
                             'on_error': 'default',
                             'default_factory': lambda: 'pika',
-                        }
+                        },
                     }
                 },
             }
@@ -1400,6 +1586,7 @@ class TestOnError:
                 'type': 'typed-dict',
                 'fields': {
                     'x': {
+                        'type': 'typed-dict-field',
                         'schema': {
                             'type': 'default',
                             'on_error': 'raise',
@@ -1408,7 +1595,7 @@ class TestOnError:
                                 'function': {'type': 'general', 'function': wrap_function},
                                 'schema': {'type': 'str'},
                             },
-                        }
+                        },
                     }
                 },
             }
@@ -1424,9 +1611,10 @@ def test_frozen_field():
         {
             'type': 'typed-dict',
             'fields': {
-                'name': {'schema': {'type': 'str'}},
-                'age': {'schema': {'type': 'int'}},
+                'name': {'type': 'typed-dict-field', 'schema': {'type': 'str'}},
+                'age': {'type': 'typed-dict-field', 'schema': {'type': 'int'}},
                 'is_developer': {
+                    'type': 'typed-dict-field',
                     'schema': {'type': 'default', 'schema': {'type': 'bool'}, 'default': True},
                     'frozen': True,
                 },
@@ -1440,5 +1628,5 @@ def test_frozen_field():
     with pytest.raises(ValidationError) as exc_info:
         v.validate_assignment(r1, 'is_developer', False)
     assert exc_info.value.errors() == [
-        {'type': 'frozen', 'loc': ('is_developer',), 'msg': 'Field is frozen', 'input': False}
+        {'type': 'frozen_field', 'loc': ('is_developer',), 'msg': 'Field is frozen', 'input': False}
     ]
